## dbt-adapters 1.2.1 - May 21, 2024

### Features

* Improvement of the compile error message in the get_fixture-sql.sql when the relation or the model not exist ([#203](https://github.com/dbt-labs/dbt-adapters/issues/203))
* Cross-database `date` macro ([#191](https://github.com/dbt-labs/dbt-adapters/issues/191))

### Fixes

* Update Clone test to reflect core change removing `deferred` attribute from nodes ([#194](https://github.com/dbt-labs/dbt-adapters/issues/194))

### Under the Hood

* Add query recording for adapters which use SQLConnectionManager ([#195](https://github.com/dbt-labs/dbt-adapters/issues/195))
* Improve memory efficiency of process_results() ([#217](https://github.com/dbt-labs/dbt-adapters/issues/217))
